===============================
hirise_tools
===============================


.. image:: https://img.shields.io/pypi/v/hirise_tools.svg
        :target: https://pypi.python.org/pypi/hirise_tools

.. image:: https://img.shields.io/travis/michaelaye/hirise_tools.svg
        :target: https://travis-ci.org/michaelaye/hirise_tools

.. image:: https://readthedocs.org/projects/hirise-tools/badge/?version=latest
        :target: https://hirise-tools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/michaelaye/hirise_tools/shield.svg
     :target: https://pyup.io/repos/github/michaelaye/hirise_tools/
     :alt: Updates


Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: ISC license
* Documentation: https://hirise-tools.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the forked `michaelaye/cookiecutter-pypackage-conda`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`michaelaye/cookiecutter-pypackage-conda`: https://github.com/michaelaye/cookiecutter-pypackage-conda
